package edu.uog.exercise.unitconverter.todolist;

import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import java.util.ArrayList;
import java.util.List;
import edu.uog.exercise.unitconverter.R;


public class ToDoListActivity extends AppCompatActivity {

    private List<ToDoItem> toDoList =new ArrayList<>();
    private ToDoAdapter toDoAdapter;
    ToDoItem toDoItem = null;

    private DatabaseHelper databaseHelper;// logbooks task 3

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_to_do_list);

        RecyclerView recyclerView =findViewById(R.id.lstView);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));
        toDoAdapter =new ToDoAdapter( toDoList );
        toDoAdapter.setListener(new ToDoAdapter.ClickListener() {
            @Override
            public void onItemClick(int position, View v, long id) {
                if (id == R.id.btnRemove ){
                    ToDoItem toDoItem1 =toDoList.remove(position);
                    toDoAdapter.setTodoList(toDoList);
                    toDoAdapter.notifyDataSetChanged();
                    removeTask(toDoItem1.getId());

                }else if (id == R.id.btnEdit ){
                    toDoItem = toDoList.get(position);
                    editRecord( toDoItem, position );

                }else if (id == R.id.btnDone ){
                    toDoItem = toDoList.get(position);
                    toDoItem.setStatus(ToDoItem.STATUS_COMPLETED);
                    toDoAdapter.setTodoList(toDoList);
                    toDoAdapter.notifyDataSetChanged();
                    updateTask( toDoItem );
                }

            }
        });
        recyclerView.setAdapter(toDoAdapter);

        databaseHelper =new DatabaseHelper(getBaseContext());// logbooks task 3
        loadData();// logbooks task 3
    }

    public void addRecord(View view){
        AlertDialog.Builder dialogBuilder = new AlertDialog.Builder(ToDoListActivity.this);

        android.view.LayoutInflater inflater = this.getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.todo_dialog, null);
        dialogBuilder.setView(dialogView);

        EditText txtName = dialogView.findViewById(R.id.txtName);
        EditText txtDescription = dialogView.findViewById(R.id.txtDescription);

        dialogBuilder.setTitle("Add todo");
        dialogBuilder.setMessage("Enter data below");
        dialogBuilder.setPositiveButton("Add", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                int id = toDoList.size()==0? 1: toDoList.get(toDoList.size()-1).getId() + 1;
                toDoItem = new ToDoItem( id,
                        txtName.getText().toString(), txtDescription.getText().toString(), ToDoItem.STATUS_TODO);
                toDoList.add(toDoItem);
                toDoAdapter.setTodoList(toDoList);
                toDoAdapter.notifyDataSetChanged();
                saveTask( toDoItem );
            }
        });
        dialogBuilder.setNegativeButton("Cancel", null);
        AlertDialog alertDialog = dialogBuilder.create();
        alertDialog.show();
    }

    public void editRecord(final ToDoItem toDoItem, int position){
        AlertDialog.Builder dialogBuilder = new AlertDialog.Builder(ToDoListActivity.this);

        android.view.LayoutInflater inflater = this.getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.todo_dialog, null);
        dialogBuilder.setView(dialogView);

        EditText txtName = dialogView.findViewById(R.id.txtName);
        txtName.setText(toDoItem.getName());
        EditText txtDescription = dialogView.findViewById(R.id.txtDescription);
        txtDescription.setText(toDoItem.getTask());

        dialogBuilder.setTitle("Edit todo");
        dialogBuilder.setMessage("Update data below");
        dialogBuilder.setPositiveButton("Update", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                toDoItem.setName( txtName.getText().toString() );
                toDoItem.setTask( txtDescription.getText().toString() );

                toDoList.set(position, toDoItem);
                toDoAdapter.setTodoList(toDoList);
                toDoAdapter.notifyDataSetChanged();

                updateTask( toDoItem );
            }
        });
        dialogBuilder.setNegativeButton("Cancel", null);
        AlertDialog alertDialog = dialogBuilder.create();
        alertDialog.show();
    }


    // logbooks task 3
    private void loadData(){
        //data read
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                try {
                    toDoList =databaseHelper.search();
                    toDoAdapter.setTodoList(toDoList);
                    toDoAdapter.notifyDataSetChanged();// refresh the data
                } catch (Exception e) { e.printStackTrace(); }
            }
        });
    }


    // logbooks task 3
    private void saveTask( ToDoItem toDoItem ){
        databaseHelper.save( toDoItem.getName(), toDoItem.getTask(), toDoItem.getStatus());
    }

    // logbooks task 3
    private void updateTask( ToDoItem toDoItem ){
        databaseHelper.update(toDoItem.getId(), toDoItem.getName(), toDoItem.getTask(), toDoItem.getStatus() );
    }

    // logbooks task 3
    private void removeTask(int id){
        databaseHelper.delete( id );
    }
}